@@ -2,7 +2,9 @@
 import Graphics.UI.Gtk
 
 import Data.Char
-import Control.Exception
+import qualified Data.Text as T
+import Control.Applicative
+import Data.Text (Text)
 
 main :: IO ()
 main = do
@@ -10,17 +12,17 @@ main = do
   dia <- dialogNew
   dialogAddButton dia stockYes ResponseYes
   dialogAddButton dia stockNo ResponseNo
-  contain <- dialogGetUpper dia
-  theText <- labelNew Nothing
-  labelSetMarkup theText arabic
-  boxPackStartDefaults contain theText
+  contain <- castToBox <$> dialogGetContentArea dia
+  theText <- labelNew (Nothing :: Maybe Text)
+  labelSetMarkup theText (T.pack arabic)
+  boxPackStart contain theText PackNatural 0
   widgetShowAll dia
   res <- dialogRun dia
   case res of
     ResponseNo -> yell
     _ -> return ()
 
-arabic :: Markup
+arabic :: String
 arabic = markSpan [FontSize (SizePoint 36)]  $
  --"Is Haskell a "++markSpan [FontForeground "red"] "fantastic"++" language?"++
  -- Do you find Haskell a fantastic language? (language has a grammatical
@@ -34,9 +36,9 @@ yell :: IO ()
 yell = do
   dia <- dialogNew
   dialogAddButton dia stockOk ResponseOk
-  contain <- dialogGetUpper dia
+  contain <- castToBox <$> dialogGetContentArea dia
   msg <- labelNew (Just "This is not an option.")
-  contain `boxPackStartDefaults` msg
+  boxPackStart contain msg PackNatural 0
   widgetShow msg
   dialogRun dia
   return ()
